==> 5.1.9.tar.gz: lib/presentation/usecase_provider.dart <==
part of '../domain/usecase_container/usecase_container.dart';

class UseCaseProvider extends InheritedWidget {
  UseCaseProvider(
    this._appState,
    this._useCaseContainer,
    this._uiState, {
    Key key,
    Widget child,
    this.persist,
  }) : super(
            key: key,
            child: (persist?.isPersistEnabled ?? false) ? _LifecycleWrapper(child: child) : child);

  final Object _appState;
  final UseCaseContainer _useCaseContainer;
  final Object _uiState;
  final PersistRepository<Object, Object> persist;

  static UseCaseProvider of(BuildContext context) =>
      context.dependOnInheritedWidgetOfExactType(aspect: UseCaseProvider);

  @override
  bool updateShouldNotify(UseCaseProvider oldWidget) => false;
}

class _LifecycleWrapper extends StatefulWidget {
  final Widget child;

  const _LifecycleWrapper({Key key, this.child}) : super(key: key);

  @override
  _LifecycleWrapperState createState() => _LifecycleWrapperState();
}

class _LifecycleWrapperState extends State<_LifecycleWrapper> with WidgetsBindingObserver {
  @override
  void initState() {
    WidgetsBinding.instance.addObserver(this);
    super.initState();
  }

  @override
  Widget build(BuildContext context) => widget.child;

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    if (state == AppLifecycleState.paused) {
      final useCaseProvider = UseCaseProvider.of(context);
      useCaseProvider.persist.save(useCaseProvider._appState, useCaseProvider._uiState);
    }
  }
}

mixin _PresenterProviderSingleChildWidget on SingleChildWidget {}

class PresenterProvider<P extends Presenter> extends SingleChildStatelessWidget
    with _PresenterProviderSingleChildWidget {
  final Widget child;
  final P presenter;

  const PresenterProvider({Key key, this.child, this.presenter}) : super(key: key, child: child);

  static P of<P extends Presenter>(BuildContext context) => Provider.of<P>(context, listen: false);

  @override
  Widget buildWithChild(BuildContext context, Widget child) {
    final useCaseProvider = UseCaseProvider.of(context);

    return Provider<P>(
      key: ValueKey('PresenterProvider: %${key.toString()}'),
      create: (_) {
        presenter?._useCaseContainer = useCaseProvider._useCaseContainer;
        presenter?._uiState = useCaseProvider?._uiState;
        presenter?.init();
        return presenter;
      },
      child: child,
      dispose: (ctx, presenter) => presenter?.dispose(),
    );
  }
}

class MultiPresenterProvider extends StatelessWidget {
  final List<SingleChildWidget> providers;
  final Widget child;

  const MultiPresenterProvider({Key key, @required this.providers, @required this.child})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: providers,
      key: ValueKey('PresenterMultiProvider: %${key.toString()}'),
      child: child,
    );
  }
}

extension PresenterProviderExtension on BuildContext {
  P presenter<P extends Presenter>() => PresenterProvider.of<P>(this);
}

==> 5.2.0.tar.gz: lib/presentation/usecase_provider.dart <==
part of '../domain/usecase_container/usecase_container.dart';

class UseCaseProvider<ST, US> extends InheritedWidget {
  UseCaseProvider(
    this._appState,
    this._useCaseContainer,
    this._uiState, {
    Key key,
    Widget child,
    this.persist,
  }) : super(
            key: key,
            child: (persist?.isPersistEnabled ?? false) ? _LifecycleWrapper(child: child) : child);

  final ST _appState;
  final UseCaseContainer _useCaseContainer;
  final US _uiState;
  final PersistRepository<ST, US> persist;

  static UseCaseProvider of(BuildContext context) =>
      context.dependOnInheritedWidgetOfExactType(aspect: UseCaseProvider);

  @override
  bool updateShouldNotify(UseCaseProvider oldWidget) => false;
}

class _LifecycleWrapper extends StatefulWidget {
  final Widget child;

  const _LifecycleWrapper({Key key, this.child}) : super(key: key);

  @override
  _LifecycleWrapperState createState() => _LifecycleWrapperState();
}

class _LifecycleWrapperState extends State<_LifecycleWrapper> with WidgetsBindingObserver {
  @override
  void initState() {
    WidgetsBinding.instance.addObserver(this);
    super.initState();
  }

  @override
  Widget build(BuildContext context) => widget.child;

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    if (state == AppLifecycleState.paused) {
      final useCaseProvider = UseCaseProvider.of(context);
      useCaseProvider.persist.save(useCaseProvider._appState, useCaseProvider._uiState);
    }
  }
}

mixin _PresenterProviderSingleChildWidget on SingleChildWidget {}

class PresenterProvider<P extends Presenter> extends SingleChildStatelessWidget
    with _PresenterProviderSingleChildWidget {
  final Widget child;
  final P presenter;

  const PresenterProvider({Key key, this.child, this.presenter}) : super(key: key, child: child);

  static P of<P extends Presenter>(BuildContext context) => Provider.of<P>(context, listen: false);

  @override
  Widget buildWithChild(BuildContext context, Widget child) {
    final useCaseProvider = UseCaseProvider.of(context);
    return Provider<P>(
      key: ValueKey('PresenterProvider: %${key.toString()}'),
      create: (_) {
        presenter?._useCaseContainer = useCaseProvider._useCaseContainer;
        presenter?._uiState = useCaseProvider?._uiState;
        presenter?.init();
        return presenter;
      },
      child: child,
      dispose: (ctx, presenter) => presenter?.dispose(),
    );
  }
}

class MultiPresenterProvider extends StatelessWidget {
  final List<SingleChildWidget> providers;
  final Widget child;

  const MultiPresenterProvider({Key key, @required this.providers, @required this.child})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: providers,
      key: ValueKey('PresenterMultiProvider: %${key.toString()}'),
      child: child,
    );
  }
}

extension PresenterProviderExtension on BuildContext {
  P presenter<P extends Presenter>() => PresenterProvider.of<P>(this);
}
